FlavorSettings class

Constructors

FlavorSettings({required String name, required String baseUrl, required Flavor flavor})

Properties

baseUrl String
final
flavor Flavor
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlavorSettings
no setter

Static Methods

init({required String name, required String baseUrl, required Flavor flavor}) → void