instance property

FlavorSettings get instance

Implementation

static FlavorSettings get instance {
  // As a senior engineer, I recognize that this getter assumes init() has been called.
  // In a production app, you might add an assertion or throw an error if _instance is null
  // to provide clearer debugging, but for performance, the direct access is fine.
  return _instance!;
}